package com.ruoyi.project.task.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.task.mapper.TTaskRepairMapper;
import com.ruoyi.project.task.domain.TTaskRepair;
import com.ruoyi.project.task.service.ITTaskRepairService;

/**
 * 维修任务Service业务层处理
 *
 * @author ruoyi
 * @date 2022-11-30
 */
@Service
public class TTaskRepairServiceImpl implements ITTaskRepairService
{
    @Autowired
    private TTaskRepairMapper tTaskRepairMapper;

    /**
     * 查询维修任务
     *
     * @param id 维修任务主键
     * @return 维修任务
     */
    @Override
    public TTaskRepair selectTTaskRepairById(Long id)
    {
        return tTaskRepairMapper.selectTTaskRepairById(id);
    }

    /**
     * 查询维修任务列表
     *
     * @param tTaskRepair 维修任务
     * @return 维修任务
     */
    @Override
    public List<TTaskRepair> selectTTaskRepairList(TTaskRepair tTaskRepair)
    {
        return tTaskRepairMapper.selectTTaskRepairList(tTaskRepair);
    }

    /**
     * 新增维修任务
     *
     * @param tTaskRepair 维修任务
     * @return 结果
     */
    @Override
    public int insertTTaskRepair(TTaskRepair tTaskRepair)
    {
        return tTaskRepairMapper.insertTTaskRepair(tTaskRepair);
    }

    /**
     * 修改维修任务
     *
     * @param tTaskRepair 维修任务
     * @return 结果
     */
    @Override
    public int updateTTaskRepair(TTaskRepair tTaskRepair)
    {
        return tTaskRepairMapper.updateTTaskRepair(tTaskRepair);
    }

    @Override
    public int updateTTaskRepairByIds(Long[] ids)
    {
        return tTaskRepairMapper.updateTTaskRepairByIds(ids);
    }

    /**
     * 批量删除维修任务
     *
     * @param ids 需要删除的维修任务主键
     * @return 结果
     */
    @Override
    public int deleteTTaskRepairByIds(Long[] ids)
    {
        return tTaskRepairMapper.deleteTTaskRepairByIds(ids);
    }

    /**
     * 删除维修任务信息
     *
     * @param id 维修任务主键
     * @return 结果
     */
    @Override
    public int deleteTTaskRepairById(Long id)
    {
        return tTaskRepairMapper.deleteTTaskRepairById(id);
    }
}
